@@ -1125,20 +1125,21 @@ about_cb (BonoboUIComponent *ui_container,
     "Hopefully, the users themselves",
     NULL
   };
-  static const gchar *license =
-    "This program is free software; you can redistribute it and/or modify\n"
-    "it under the terms of the GNU General Public License as published by\n"
-    "the Free Software Foundation; either version 2 of the License, or\n"
-    "(at your option) any later version.\n"
-    "\n"
-    "This program is distributed in the hope that it will be useful,\n"
-    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-    "GNU General Public License for more details.\n"
-    "\n"
-    "You should have received a copy of the GNU General Public License\n"
-    "along with this program; if not, write to the Free Software\n"
-    "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n";
+  static const gchar *license[] = {
+    N_("The Fast User Switch Applet is free software; you can redistribute it and/or modify "
+       "it under the terms of the GNU General Public License as published by "
+       "the Free Software Foundation; either version 2 of the License, or "
+       "(at your option) any later version."),
+    N_("This program is distributed in the hope that it will be useful, "
+       "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+       "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+       "GNU General Public License for more details."),
+    N_("You should have received a copy of the GNU General Public License "
+       "along with this program; if not, write to the Free Software "
+        "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA "),
+    NULL
+  };
+  gchar *license_i18n;
 
   if (about)
     {
@@ -1174,7 +1175,9 @@ about_cb (BonoboUIComponent *ui_container,
    */
   gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about),
 					   _("translator-credits"));
-  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about), license);
+  license_i18n = g_strjoinv ("\n\n", license);
+  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about), license_i18n);
+  g_free (license_i18n);
 
   g_object_add_weak_pointer (G_OBJECT (about),
 			     (gpointer *) &about);
@@ -2338,14 +2341,13 @@ static gboolean
 system_can_do_xnest (void)
 {
   gchar *tmp;
+  gboolean retval;
 
   tmp = g_find_program_in_path ("Xnest");
+  retval = (tmp != NULL ? TRUE : FALSE);
   g_free (tmp);
 
-  if (!tmp && g_file_test ("/usr/X11R6/bin/Xnest", G_FILE_TEST_EXISTS))
-    tmp = GUINT_TO_POINTER (!NULL);
-
-  return (tmp != NULL);
+  return retval;
 }
 
 static void
